{% import "macros/form.html" as form %}

<form id="user-register-form" action="" method="post">
  {{ form.errors(error_summary) }}
  {{ form.input("name", id="field-username", label=_("Username"), placeholder=_("username"), value=data.name, error=errors.name, classes=["control-medium"], is_required=True) }}
  {{ form.input("fullname", id="field-fullname", label=_("Full Name"), placeholder=_("Joe Bloggs"), value=data.fullname, error=errors.fullname, classes=["control-medium"]) }}
  {{ form.input("email1", id="field-email", label=_("Email"), type="email", placeholder=_("joe@example.com"), value=data.email1, error=errors.email, classes=["control-medium"], is_required=True) }}
  {{ form.input("email2", id="field-confirm-email", label=_("Confirm Email"), type="email", placeholder=_("joe@example.com"), value=data.email2, error=errors.email, classes=["control-medium"], is_required=True) }}
  {{ form.input("password1", id="field-password", label=_("Password"), type="password", placeholder="••••••••", value=data.password1, error=errors.password1, classes=["control-medium"], is_required=True) }}
  {{ form.input("password2", id="field-confirm-password", label=_("Confirm Password"), type="password", placeholder="••••••••", value=data.password2, error=errors.password1, classes=["control-medium"], is_required=True) }}

  {% if g.recaptcha_publickey %}
    {% snippet "user/snippets/recaptcha.html", public_key=g.recaptcha_publickey %}
  {% endif %}

  {{ form.required_message() }}

  <div class="form-actions">
    {% block form_actions %}
    <button class="btn btn-primary" type="submit" name="save">{{ _("Create Account") }}</button>
    {% endblock %}
  </div>
</form>
